@@ -1,3 +1,17 @@
+#' Index of US Industrial Production
+#'
+#' Index of US industrial production (1985 = 100).
+#'
+#' This is a transformation into simple data.frame
+#' of data `USProdIndex` in package 'AER'.
+#'
+#' @name us_indus_prod
+#' @docType data
+#' @keywords datasets
+#' @usage data(us_indus_prod)
+#' @format A data frame with 256 rows and 3 variables
+NULL
+
 #' Dummy dataset for barchart
 #'
 #' A dataset containing 2 categorical and an integer variables:
